## [1.1.1]

## Modified
- Changed github actions pypi publish workflow to use tokens

## [1.1.0]

## Modified
- Added link to google colab from notebooks

## Added
- Added index.html in docs folder 

## [1.0.0]

### Added
- API for volume and point upload
- Local bucket API
- Additional docs for new volume and point features

## [0.2.0]

### Modified
- Modified documentation and API to refer to atlas.internationalbrainlab.org (before atlas2)

## [0.1.1]

### Modified
- HOTFIX: Fix for token to be passed in

## [0.1.0]

### Added
 - API and mapping files that were located in the ephys-atlas-web github repository.